pub struct CharAttribute {
pub foreground: Color,
pub background: Color,
pub flags: CharFlags,
}Expand description
Represents attributes of a character such as foreground color, background color, and flags.
Fields
foreground: Colorbackground: Colorflags: CharFlagsImplementations
Sourceimpl CharAttribute
impl CharAttribute
Sourcepub fn with_color(fore: Color, back: Color) -> CharAttribute
pub fn with_color(fore: Color, back: Color) -> CharAttribute
Creates a new CharAttribute with the specified foreground and background colors.
The flags are set to CharFlags::None.
Example
use appcui::prelude::*;
let attr = CharAttribute::with_color(Color::Red, Color::Black);Sourcepub fn with_fore_color(fore: Color) -> CharAttribute
pub fn with_fore_color(fore: Color) -> CharAttribute
Creates a new CharAttribute with the specified foreground color.
The background color is set to Color::Transparent and the flags are set to CharFlags::None.
Example
use appcui::prelude::*;
let attr = CharAttribute::with_fore_color(Color::Red);Sourcepub fn with_back_color(back: Color) -> CharAttribute
pub fn with_back_color(back: Color) -> CharAttribute
Creates a new CharAttribute with the specified background color.
The foreground color is set to Color::Transparent and the flags are set to CharFlags::None.
Example
use appcui::prelude::*;
let attr = CharAttribute::with_back_color(Color::Black);Trait Implementations
Sourceimpl Clone for CharAttribute
impl Clone for CharAttribute
Sourcefn clone(&self) -> CharAttribute
fn clone(&self) -> CharAttribute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CharAttribute
Sourceimpl Debug for CharAttribute
impl Debug for CharAttribute
Sourceimpl Default for CharAttribute
impl Default for CharAttribute
Sourceimpl PartialEq for CharAttribute
impl PartialEq for CharAttribute
Sourcefn eq(&self, other: &CharAttribute) -> bool
fn eq(&self, other: &CharAttribute) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CharAttribute