Key

Struct Key 

pub struct Key {
    pub code: KeyCode,
    pub modifier: KeyModifier,
}
Represents a keyboard key and its modifier.

This struct contains a KeyCode and a KeyModifier.

Fields

  • code - The code of the key.
  • modifier - The modifier of the key.

Fields

code: KeyCodemodifier: KeyModifier

Implementations

Source

impl Key

pub const None: Key

Represents a non-existent key.

pub fn new(code: KeyCode, modifier: KeyModifier) -> Key

Creates a new key with the given code and modifier.

Arguments
  • code - The code of the key.
  • modifier - The modifier of the key.
Returns

A new key created from the code and modifier.

Example
use appcui::prelude::*;
 
let key = Key::new(KeyCode::A, KeyModifier::Shift|KeyModifier::Alt);
pub fn create_hotkey(character: char, modifier: KeyModifier) -> Key

Creates a new key from a character and a modifier.

Arguments
  • character - The character to create the key from.
  • modifier - The modifier of the key.
Returns

A new key created from the character and modifier.

Example
use appcui::prelude::*;
 
let key = Key::create_hotkey('a', KeyModifier::Alt);
pub fn value(&self) -> u16

Returns the value of the key as a u16. This is usually used in combination with the macro key! in a match statement.

Returns

The value of the key as a u16.

Example
use appcui::prelude::*;
 
let key = Key::new(KeyCode::A, KeyModifier::Shift);
let value = key.value();