Struct BackgroundTaskConector

pub struct BackgroundTaskConector<T: Send + 'static, R: Send + 'static> { /* private fields */ }

Implementations

Source

impl<T, R> BackgroundTaskConector<T, R>
where T: Send + 'static, R: Send + 'static,

pub fn notify(&self, data: T) -> bool

Notify the main thread with some data. Returns true if the data was sent successfully. This method works asynchronously.

pub fn query(&self, data: T) -> Option<R>

Query the main thread with some data. Returns the result of the query. This method works synchronously.

pub fn should_stop(&self) -> bool

If there is a task request to pause the task from the main thread, it pauses the task and waits until the task is resumed. If there is a task request to close the task from the main thread, it returns true. Otherwise, it returns false. This method should be used in the background task to validate that the task should continue.

Example
use appcui::prelude::*;

fn run_background_task_function<T,R>(conector: &BackgroundTaskConector<T, R>)
where
    T:Send+'static,
    R:Send+'static
{
    loop {
       if !conector.should_stop() { break; }
       // do some tasks
    }
}