pub struct AppBar { /* private fields */ }Implementations
Sourceimpl AppBar
impl AppBar
Sourcepub fn get_mut<T>(&mut self, appbaritem_handle: Handle<T>) -> Option<&mut T>where
T: Into<AppBarItem>,
pub fn get_mut<T>(&mut self, appbaritem_handle: Handle<T>) -> Option<&mut T>where
T: Into<AppBarItem>,
Get a mutable reference to an item from the app bar by its handle. The item has to be converted to an AppBarItem.
Arguments
appbaritem_handle- The handle of the item to get
Returns
An option containing a mutable reference to the item if found, or None if the item doesn’t exist or the handle is invalid
Sourcepub fn show<T>(&mut self, handle: Handle<T>)where
T: Into<AppBarItem>,
pub fn show<T>(&mut self, handle: Handle<T>)where
T: Into<AppBarItem>,
Show an item in the app bar. The item has to be converted to an AppBarItem. This method should only be called in AppBarEvents::on_update(…) method (if overwritten). By default, all items are hidden and whenever the focus changes, the AppCUI framework hides all items and starts from the focus control and moves to its parent and calls this method to show the items.
Remark: If you don’t implement AppBarEvents::on_update(…) method, if does not matter that you have added items to your AppBar - they will be hidden (unless you call .show(…) method).
Arguments
handle- The handle of the item to show