pub struct Flags { /* private fields */ }Implementations
Sourceimpl Flags
impl Flags
pub const ScrollBars: Flags
pub const SearchBar: Flags
pub const CheckBoxes: Flags
pub const AutoScroll: Flags
pub const HighlightSelectedItemWhenInactive: Flags
pub const None: Flags
Sourcepub fn from_value(value: u8) -> Option<Self>
pub fn from_value(value: u8) -> Option<Self>
This function allows creating a new Flags object from an u8 value.
This method returns Some(Flags) if the parameter value is a valid bit configuration, or None otherwise.
Example
use EnumBitFlags::EnumBitFlags;
#[EnumBitFlags]
enum MyFlags {
Flag_1 = 0x0001,
Flag_2 = 0x0002,
Flag_3 = 0x0004
}
if let Some(y) = MyFlags::from_value(5) {
println!("{y}");
}
else {
eprintln!("Could not create value!");
}Sourcepub fn contains_one(&self, mask: Flags) -> bool
pub fn contains_one(&self, mask: Flags) -> bool
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Checks if the current value is not set or if disable_empty_generation is false and the object is the empty value
Returns
trueif the current value is not set or is the empty value.falseotherwise.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clears the value or sets it to the empty value.
Returns
trueif the current value is not set or is the empty value.falseotherwise.
Sourcepub fn remove(&mut self, mask: Flags)
pub fn remove(&mut self, mask: Flags)
Removes the values set in the mask parameter from the current value.
Parameters
mask: AFlagsvalue representing the mask to remove.