pub struct Panel { /* private fields */ }Implementations
Sourceimpl Panel
impl Panel
Sourcepub fn new(caption: &str, layout: Layout) -> Self
pub fn new(caption: &str, layout: Layout) -> Self
Creates a new Panel control with the specified caption and layout. The type of the panel will be obtained from the current theme.
Example
use appcui::prelude::*;
let mut panel = Panel::new("Panel",
layout!("x:1,y:1,w:20,h:10"));Sourcepub fn with_type(caption: &str, layout: Layout, panel_type: Type) -> Self
pub fn with_type(caption: &str, layout: Layout, panel_type: Type) -> Self
Creates a new Panel control with the specified caption, layout and type. The panel type is one of the following values:
Type::Border- a panel with a border around itType::Window- a panel with a border around it and a title barType::Page- a panel without a border, used to group controlsType::TopBar- a panel without a border, used to group controls and to display a title barType::Raised- a panel with a 3D raised borderType::Sunken- a panel with a 3D sunken border
Example
use appcui::prelude::*;
let mut panel = Panel::with_type("Panel",
layout!("x:1,y:1,w:20,h:10"),
panel::Type::Border);pub fn inner_create( caption: &str, layout: Layout, panel_type: Type, status: StatusFlags, ) -> Self
Sourcepub fn set_title(&mut self, text: &str)
pub fn set_title(&mut self, text: &str)
Sets the title of the panel. The title is displayed only if the panel type is Type::Window , Type::TopBar or
Sourcepub fn panel_type(&self) -> Type
pub fn panel_type(&self) -> Type
Returns the type of the panel
Sourcepub fn add<T>(&mut self, control: T) -> Handle<T>
pub fn add<T>(&mut self, control: T) -> Handle<T>
Adds a new control to the panel. The control will be added as a child of the panel and will be automatically removed when the panel is destroyed. Returns a handle to the newly created control.
Example
use appcui::prelude::*;
let mut panel = Panel::new("Panel", layout!("x:1,y:1,w:10,h:10"));
let handle_button = panel.add(Button::new("Button", layout!("x:1,y:1,w:8")));Methods from Deref<Target = ControlBase>
Sourcepub fn client_size(&self) -> Size
pub fn client_size(&self) -> Size
Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.
Sourcepub fn set_size(&mut self, width: u16, height: u16)
pub fn set_size(&mut self, width: u16, height: u16)
Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn position(&self) -> Point
pub fn position(&self) -> Point
Returns the relatove position (x,y) of the current control to its parent.
Sourcepub fn set_position(&mut self, x: i32, y: i32)
pub fn set_position(&mut self, x: i32, y: i32)
Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.
Sourcepub fn set_visible(&mut self, visible: bool)
pub fn set_visible(&mut self, visible: bool)
Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.
Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the buttonpub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)
pub fn expanded_size(&self) -> Size
Sourcepub fn request_focus(&mut self) -> bool
pub fn request_focus(&mut self) -> bool
A control can use this method to request focus
pub fn timer(&mut self) -> Option<&mut Timer>
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Returns true if the current control is visible or false otherwise
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if the current control is enabled or false otherwise
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Returns true if the current control is active (enabled and visible at the same time) or false otherwise
Sourcepub fn can_receive_input(&self) -> bool
pub fn can_receive_input(&self) -> bool
Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.
Sourcepub fn has_focus(&self) -> bool
pub fn has_focus(&self) -> bool
Returns true if the current control has the focus or false otherwise
Sourcepub fn is_mouse_over(&self) -> bool
pub fn is_mouse_over(&self) -> bool
Returns true if the mouse cursor is over the current control or false otherwise
Sourcepub fn set_size_bounds(
&mut self,
min_width: u16,
min_height: u16,
max_width: u16,
max_height: u16,
)
pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )
Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.
Sourcepub fn set_hotkey<T>(&mut self, hotkey: T)
pub fn set_hotkey<T>(&mut self, hotkey: T)
Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey
pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)
pub fn request_update(&self)
pub fn appbar(&mut self) -> &mut AppBar
pub fn theme(&self) -> &Theme
Sourcepub fn update_layout(&mut self, layout: Layout)
pub fn update_layout(&mut self, layout: Layout)
Updates the layout of the current control