ToggleButton

Struct ToggleButton 

pub struct ToggleButton { /* private fields */ }
A button that stays pressed or released and can participate in exclusive groups.

ToggleButton shows a caption (and optional tooltip) and raises a selection event when its state changes. In single-selection mode, activating one button deselects its siblings. Visual style is controlled by Type.

Implementations

Source

impl ToggleButton

pub fn new( caption: &str, tooltip: &str, layout: Layout, selected: bool, button_type: Type, ) -> Self

Creates a new toggle button with the specified caption, tooltip, layout, selected state and button type.
The button type can be Normal or Underlined.

Examples
use appcui::prelude::*;
let mut button = ToggleButton::new("🐼", 
                                   "Enable Panda Mode", 
                                   layout!("x:1,y:1,w:2"), 
                                   false, 
                                   togglebutton::Type::Normal);
pub fn with_single_selection( caption: &str, tooltip: &str, layout: Layout, selected: bool, button_type: Type, ) -> Self

Creates a new toggle button with the specified caption, tooltip, layout, selected state and button type. The button type can be Normal or Underlined. This type of button is considered to be part of a group of buttons, and only one button can be selected at a time.

Example:

use appcui::prelude::*;
let panda = ToggleButton::with_single_selection("🐼",
                                                "Enable Panda Mode",
                                                layout!("x:1,y:1,w:2"),
                                                false,
                                                togglebutton::Type::Normal);
let dog = ToggleButton::with_single_selection("🐶",
                                              "Enable Dog Mode",
                                              layout!("x:3,y:1,w:2"),
                                              true,
                                              togglebutton::Type::Normal);
pub fn set_caption(&mut self, caption: &str)

Sets the caption of a toggle button.

pub fn caption(&self) -> &str

Returns the toggle button caption.

pub fn is_selected(&self) -> bool

Returns the state of the toggle button (pressed or not)

pub fn set_selected(&mut self, selected: bool)

Sets the state of the toggle button (pressed or not).

If the button is part of a group of buttons, only one button can be selected at a time. As such, calling this function in this case with a false value will have no effect.

Methods from Deref<Target = ControlBase>

pub fn size(&self) -> Size

Returns the size of a control

pub fn client_size(&self) -> Size

Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.

pub fn set_size(&mut self, width: u16, height: u16)

Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed. This method has no effect on a Desktop control.

pub fn position(&self) -> Point

Returns the relatove position (x,y) of the current control to its parent.

pub fn set_position(&mut self, x: i32, y: i32)

Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed. This method has no effect on a Desktop control.

pub fn set_enabled(&mut self, enabled: bool)

Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.

pub fn set_visible(&mut self, visible: bool)

Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.

Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the button
pub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)

pub fn expanded_size(&self) -> Size

pub fn request_focus(&mut self) -> bool

A control can use this method to request focus

pub fn timer(&mut self) -> Option<&mut Timer>

pub fn is_visible(&self) -> bool

Returns true if the current control is visible or false otherwise

pub fn is_enabled(&self) -> bool

Returns true if the current control is enabled or false otherwise

pub fn is_active(&self) -> bool

Returns true if the current control is active (enabled and visible at the same time) or false otherwise

pub fn can_receive_input(&self) -> bool

Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.

pub fn has_focus(&self) -> bool

Returns true if the current control has the focus or false otherwise

pub fn is_mouse_over(&self) -> bool

Returns true if the mouse cursor is over the current control or false otherwise

pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )

Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.

pub fn set_hotkey<T>(&mut self, hotkey: T)
where Key: From<T>,

Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey

pub fn hotkey(&self) -> Key

Returns the hotkey associated to a control or Key::None otherwise.

pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)

pub fn request_update(&self)

pub fn register_menu(&mut self, menu: Menu) -> Handle<Menu>

pub fn show_menu( &self, handle: Handle<Menu>, x: i32, y: i32, max_size: Option<Size>, )

pub fn menuitem<T>( &self, menu_handle: Handle<Menu>, menuitem_handle: Handle<T>, ) -> Option<&T>
where T: MenuItem,

pub fn menuitem_mut<T>( &mut self, menu_handle: Handle<Menu>, menuitem_handle: Handle<T>, ) -> Option<&mut T>
where T: MenuItem,

pub fn appbar(&mut self) -> &mut AppBar

pub fn theme(&self) -> &Theme

pub fn update_layout(&mut self, layout: Layout)

Updates the layout of the current control