Module treeview

Module treeview 

A treeview UI control for displaying hierarchical data.

The TreeView control provides a way to display tree-structured data with collapsible nodes. It supports multiple selection modes, custom node rendering, and keyboard navigation.

Re-exports

pub use crate::ui::components::listitem::ListItem;
pub use crate::ui::components::listitem::RenderMethod;

Modules

events
Events emitted by a super::TreeView.

Structs

Flags
Initialization flags for a super::TreeView.
Item
A node in a super::TreeView, wrapping a ListItem value and parent/child links.
TreeView
A hierarchical, multi-column view of items that implement ListItem.

Enums

AreaFormat
Unit used when rendering an area value in a list item.
BoolFormat
How a boolean list-item value is rendered as text.
CurrencyFormat
Currency and symbol used when rendering a monetary list-item value.
DateFormat
How a calendar-date list-item value is rendered.
DateTimeFormat
How a date-and-time list-item value is rendered.
DistanceFormat
Unit used when rendering a distance list-item value.
DurationFormat
How a duration list-item value is rendered.
FloatFormat
Precision and grouping used when rendering a floating-point list-item value.
NumericFormat
How an integer list-item value is rendered.
PercentageFormat
How a percentage list-item value is rendered.
RatingFormat
How a rating list-item value is rendered.
SizeFormat
Unit used when rendering a byte-size list-item value.
SpeedFormat
Unit used when rendering a speed list-item value.
Status
Progress or lifecycle state of a list-item task.
StatusFormat
Visual style used when rendering a Status bar in a list item.
TemperatureFormat
Temperature scale used when rendering a list-item value.
TimeFormat
How a time-of-day list-item value is rendered.
VolumeFormat
Unit used when rendering a volume list-item value.
WeightFormat
Unit used when rendering a weight list-item value.