TreeView

Struct TreeView 

pub struct TreeView<T>
where T: ListItem + 'static,
{ /* private fields */ }
A hierarchical, multi-column view of items that implement ListItem.

TreeView displays parent-child relationships with fold/expand controls, optional columns, search, and selection. Tree and column behavior are controlled by Flags.

Implementations

Source

impl<T> TreeView<T>
where T: ListItem + 'static,

pub fn new(layout: Layout, flags: Flags) -> Self

Creates a new TreeView control with the specified layout and flags

Example
use appcui::prelude::*;

#[derive(ListItem)]
struct FileInfo {
   #[Column(name="Name", width=20)]
   name: &'static str,
   #[Column(name="Folder", width=10)]
   folder: bool
}
let mut tree = TreeView::<FileInfo>::new(layout!("d:f"), treeview::Flags::None);
pub fn with_capacity(capacity: usize, layout: Layout, flags: Flags) -> Self

Creates a new TreeView control with the specified layout and flags. The capacity parameter specifies the initial number of items that can be stored in the tree view.

Example
use appcui::prelude::*;

#[derive(ListItem)]
struct FileInfo {
   #[Column(name="Name", width=20)]
   name: &'static str,
   #[Column(name="Folder", width=10)]
   folder: bool
}
let mut tree = TreeView::<FileInfo>::with_capacity(16, layout!("d:f"), treeview::Flags::None);
pub fn add(&mut self, item: T) -> Handle<Item<T>>

Adds a new object to the tree view. The object must implement ListItem trait. The object will be added as a root item. This method returns a handle to the newly added item.

Example
use appcui::prelude::*;

#[derive(ListItem)]
struct FileInfo {
   #[Column(name="Name", width=20)]
   name: &'static str,
   #[Column(name="Folder", width=10)]
   folder: bool
}
let mut tree = TreeView::<FileInfo>::new(layout!("d:f"), treeview::Flags::None);
tree.add(FileInfo { name: "Folder", folder: true });
pub fn add_to_parent( &mut self, item: T, parent: Handle<Item<T>>, ) -> Handle<Item<T>>

Adds a new object to the tree view. The object must implement ListItem trait. The object will be added as a child of the specified parent item. This method returns a handle to the newly added item.

Example
use appcui::prelude::*;

#[derive(ListItem)]
struct FileInfo {
   #[Column(name="Name", width=20)]
   name: &'static str,
   #[Column(name="Folder", width=10)]
   folder: bool
}
let mut tree = TreeView::<FileInfo>::new(layout!("d:f"), treeview::Flags::None);
let parent = tree.add(FileInfo { name: "Folder", folder: true });
tree.add_to_parent(FileInfo { name: "File", folder: false }, parent);
pub fn add_item(&mut self, item: Item<T>) -> Handle<Item<T>>

Adds a new item to the tree view. The item will be added as a root item and will allow someone to control the selection state, icon and attributes.

Example
use appcui::prelude::*;

#[derive(ListItem)]
struct FileInfo {
   #[Column(name="Name", width=20)]
   name: &'static str,
   #[Column(name="Folder", width=10)]
   folder: bool
}
let mut tree = TreeView::<FileInfo>::new(layout!("d:f"), treeview::Flags::None);
let h = tree.add_item(treeview::Item::new(
        FileInfo { name: "Folder", folder: true },
        false,
        Some(charattr!("white")),
        ['F', 'D']));
pub fn add_item_to_parent( &mut self, item: Item<T>, parent: Handle<Item<T>>, ) -> Handle<Item<T>>

Adds a new item to the tree view. The item will be added as a child of the specified parent item and will allow someone to control the selection state, icon and attributes. This method returns a handle to the newly added item.

Example
use appcui::prelude::*;

#[derive(ListItem)]
struct FileInfo {
   #[Column(name="Name", width=20)]
   name: &'static str,
   #[Column(name="Folder", width=10)]
   folder: bool
}

let mut tree = TreeView::<FileInfo>::new(layout!("d:f"), treeview::Flags::None);
let parent = tree.add(FileInfo { name: "Folder", folder: true });
tree.add_item_to_parent(treeview::Item::new(
       FileInfo { name: "File", folder: false },
       false,
       Some(charattr!("white")),
       ['F', 'D']), parent);
pub fn add_batch<F>(&mut self, f: F)
where F: FnOnce(&mut Self),

Adds multiple items to a tree view and then sorts and refilters the list. This method is useful when you want to add multiple items at once.

pub fn set_frozen_columns(&mut self, count: u16)

Sets the number of frozen columns. Frozen columns are columns that are always visible, even when the list view is scrolled horizontally. The frozen columns are always the first columns in the list view. Using the value 0 will disable frozen columns.

pub fn move_cursor_to(&mut self, handle: Handle<Item<T>>) -> bool

Moves the cursor to a specified item. That item has to be visible in the tree view. If the item is not visible, the method will return false.

pub fn item(&self, item_handle: Handle<Item<T>>) -> Option<&Item<T>>

Returns a immutable reference of the item with a specified handle or None if the handle is invalid (e.g. the handle does not exist in the tree view)

pub fn item_mut(&mut self, item_handle: Handle<Item<T>>) -> Option<&mut Item<T>>

Returns a mutable reference of the item with a specified handle or None if the handle is invalid (e.g. the handle does not exist in the tree view)

pub fn current_item_handle(&self) -> Option<Handle<Item<T>>>

Returns the handle of the current item (the item where the cursor is located) or None if there are no items in the tree view

pub fn current_item(&self) -> Option<&Item<T>>

Returns a immutable reference to the current item (the item where the cursor is located) or None if there are no items in the tree view

pub fn current_item_mut(&mut self) -> Option<&mut Item<T>>

Returns a mutable reference to the current item (the item where the cursor is located) or None if there are no items in the tree view

pub fn root_items(&self) -> &[Handle<Item<T>>]

Returns a slice with the handles of all root level items

pub fn root_item(&self, index: usize) -> Option<&Item<T>>

Returns a mutable reference to the root item at the specified index or None if the index is invalid

pub fn root_item_mut(&mut self, index: usize) -> Option<&mut Item<T>>

Returns a mutable reference to the root item at the specified index or None if the index is invalid

pub fn delete_item(&mut self, item_handle: Handle<Item<T>>)

Deletes the item with the specified handle. If the item has children, they will be deleted as well.

pub fn clear(&mut self)

Deletes all items in the tree view

pub fn delete_item_children(&mut self, item_handle: Handle<Item<T>>)

Recursively deletes all children of the item with the specified handle (but keeps the item itself)

pub fn collapse_item(&mut self, item_handle: Handle<Item<T>>, recursive: bool)

Collapses the item with the specified handle. If the recursive flag is set to true, all children of the item will be collapsed as well.

pub fn expand_item(&mut self, item_handle: Handle<Item<T>>, recursive: bool)

Expands the item with the specified handle. If the recursive flag is set to true, all children of the item will be expanded as well.

pub fn collapse_all(&mut self)

Collapses all items in the tree view

pub fn expand_all(&mut self)

Expands all items in the tree view

pub fn items_count(&self) -> usize

Returns the number of items in the tree view

pub fn selected_items_count(&self) -> usize

Returns the number of selected items

pub fn select_item(&mut self, item_handle: Handle<Item<T>>, selected: bool)

Change the selection state of the item at the specified index

pub fn sort(&mut self, column_index: u16, ascendent: bool)

Sort the items in the tree view based on the specified column index. The ascendent flag specifies the sorting order (true for ascending, false for descending)

Clears the content of the search bar

Methods from Deref<Target = ControlBase>

pub fn size(&self) -> Size

Returns the size of a control

pub fn client_size(&self) -> Size

Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.

pub fn set_size(&mut self, width: u16, height: u16)

Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed. This method has no effect on a Desktop control.

pub fn position(&self) -> Point

Returns the relatove position (x,y) of the current control to its parent.

pub fn set_position(&mut self, x: i32, y: i32)

Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed. This method has no effect on a Desktop control.

pub fn set_enabled(&mut self, enabled: bool)

Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.

pub fn set_visible(&mut self, visible: bool)

Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.

Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the button
pub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)

pub fn expanded_size(&self) -> Size

pub fn request_focus(&mut self) -> bool

A control can use this method to request focus

pub fn timer(&mut self) -> Option<&mut Timer>

pub fn is_visible(&self) -> bool

Returns true if the current control is visible or false otherwise

pub fn is_enabled(&self) -> bool

Returns true if the current control is enabled or false otherwise

pub fn is_active(&self) -> bool

Returns true if the current control is active (enabled and visible at the same time) or false otherwise

pub fn can_receive_input(&self) -> bool

Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.

pub fn has_focus(&self) -> bool

Returns true if the current control has the focus or false otherwise

pub fn is_mouse_over(&self) -> bool

Returns true if the mouse cursor is over the current control or false otherwise

pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )

Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.

pub fn set_hotkey<T>(&mut self, hotkey: T)
where Key: From<T>,

Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey

pub fn hotkey(&self) -> Key

Returns the hotkey associated to a control or Key::None otherwise.

pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)

pub fn request_update(&self)

pub fn register_menu(&mut self, menu: Menu) -> Handle<Menu>

pub fn show_menu( &self, handle: Handle<Menu>, x: i32, y: i32, max_size: Option<Size>, )

pub fn menuitem<T>( &self, menu_handle: Handle<Menu>, menuitem_handle: Handle<T>, ) -> Option<&T>
where T: MenuItem,

pub fn menuitem_mut<T>( &mut self, menu_handle: Handle<Menu>, menuitem_handle: Handle<T>, ) -> Option<&mut T>
where T: MenuItem,

pub fn appbar(&mut self) -> &mut AppBar

pub fn theme(&self) -> &Theme

pub fn update_layout(&mut self, layout: Layout)

Updates the layout of the current control