pub fn error(title: &str, caption: &str)Expand description
Displays an error dialog with an “Ok” button.
This function shows a modal error dialog with the specified title and message. The dialog will have a single “Ok” button and will block until the user dismisses it.
Arguments
title- The title of the dialog.caption- The message to display in the dialog.
Example
use appcui::dialogs;
dialogs::error("Error", "An error has occurred during the last operation");