pub struct BitTile<const STORAGE_BYTES: usize> { /* private fields */ }Expand description
A bit tile is a 2D array of bits. It is used to store a 2D image in a compact way (where a pixel is represented by a single bit that can be either set or unset) The size of the bit tile is the STORAGE_BYTES generic parameter plus 2 bytes for the width and height. Since the width and height are stored in 2 bytes, the maximum size of the bit tile is 255 x 255 pixels. However, the STORAGE_BYTES parameter is limited to 1024 bytes, so the size of the tile should fit in this space.
Implementations
Sourceimpl<const STORAGE_BYTES: usize> BitTile<STORAGE_BYTES>
impl<const STORAGE_BYTES: usize> BitTile<STORAGE_BYTES>
Sourcepub fn new(width: u8, height: u8) -> Option<Self>
pub fn new(width: u8, height: u8) -> Option<Self>
Creates a new bit tile with the specified width and height.
Arguments
width- The width of the bit tile in pixels.height- The height of the bit tile in pixels.
Returns
Some(BitTile)- If the bit tile was created successfully.None- If the width or height is 0 or if the bit tile does not fit in the allocated space.
Sourcepub fn set(&mut self, x: u32, y: u32, value: bool)
pub fn set(&mut self, x: u32, y: u32, value: bool)
Sets the value of the pixel (set or unset) at the specified coordinates. If the coordinates are outside the bounds of the bit tile, the operation is silently ignored.
Arguments
x- The x coordinate of the pixel.y- The y coordinate of the pixel.value- The value of the pixel (set or unset).
Sourcepub fn clear(&mut self, value: bool)
pub fn clear(&mut self, value: bool)
Clears the bit tile by setting all pixels to the specified value.
Arguments
value- The value to set all pixels to (set or unset).
Sourcepub fn to_string_format(&self) -> String
pub fn to_string_format(&self) -> String
Returns a string representation of the bit tile in the format of:
|...XX....XX...|
|..XXXX..XXXX..|
|.XXXXXXXXXXXX.|
|.XXXXXXXXXXXX.|
|..XXXXXXXXXX..|
|...XXXXXXXX...|
|....XXXXXX....|
|.....XXXX.....|
|......XX......|where:
X- a pixel that is set.- a pixel that is unset|- the start and end of a row
Returns
String- The string representation of the bit tile.