pub struct BackgroundTask<T: Send + 'static, R: Send + 'static> { /* private fields */ }Implementations
Sourceimpl<T: Send, R: Send> BackgroundTask<T, R>
impl<T: Send, R: Send> BackgroundTask<T, R>
Sourcepub fn run(
task: fn(conector: &BackgroundTaskConector<T, R>),
receiver: Handle<Window>,
) -> Handle<BackgroundTask<T, R>>
pub fn run( task: fn(conector: &BackgroundTaskConector<T, R>), receiver: Handle<Window>, ) -> Handle<BackgroundTask<T, R>>
Starts a new background task. The task will run in a separate thread. The task will receive a conector that can be used to send and receive data from the main thread.
Sourcepub fn read(&self) -> Option<T>
pub fn read(&self) -> Option<T>
Reads the data sent by the background task. If there is no data, it returns None. This method is not meant to be used directly (it will be used by the generated code).
Sourcepub fn send(&self, value: R)
pub fn send(&self, value: R)
Sends data to the background task. This method is not meant to be used directly (it will be used by the generated code).
Sourcepub fn pause(&self)
pub fn pause(&self)
Request the background task to pause. For this method to work, the background task must use the should_stop() method
Sourcepub fn resume(&self)
pub fn resume(&self)
Request the background task to resume. For this method to work, the background task must use the should_stop() method
Sourcepub fn stop(&self)
pub fn stop(&self)
Request the background task to stop. For this method to work, the background task must use the should_stop() method
Sourcepub fn update_control_handle(&self, control_handle: Handle<()>)
pub fn update_control_handle(&self, control_handle: Handle<()>)
Updates the control handle of the background task for scenarios when the current window that receives the data is replaced.