pub struct BackgroundTaskConector<T: Send + 'static, R: Send + 'static> { /* private fields */ }Implementations
Sourceimpl<T, R> BackgroundTaskConector<T, R>
impl<T, R> BackgroundTaskConector<T, R>
Sourcepub fn notify(&self, data: T) -> bool
pub fn notify(&self, data: T) -> bool
Notify the main thread with some data. Returns true if the data was sent successfully. This method works asynchronously.
Sourcepub fn query(&self, data: T) -> Option<R>
pub fn query(&self, data: T) -> Option<R>
Query the main thread with some data. Returns the result of the query. This method works synchronously.
Sourcepub fn should_stop(&self) -> bool
pub fn should_stop(&self) -> bool
If there is a task request to pause the task from the main thread, it pauses the task and waits until the task is resumed. If there is a task request to close the task from the main thread, it returns true. Otherwise, it returns false. This method should be used in the background task to validate that the task should continue.
Example
use appcui::prelude::*;
fn run_background_task_function<T,R>(conector: &BackgroundTaskConector<T, R>)
where
T:Send+'static,
R:Send+'static
{
loop {
if !conector.should_stop() { break; }
// do some tasks
}
}Auto Trait Implementations
impl<T, R> Freeze for BackgroundTaskConector<T, R>
impl<T, R> RefUnwindSafe for BackgroundTaskConector<T, R>where
T: RefUnwindSafe,
R: RefUnwindSafe,
impl<T, R> Send for BackgroundTaskConector<T, R>
impl<T, R> !Sync for BackgroundTaskConector<T, R>
impl<T, R> Unpin for BackgroundTaskConector<T, R>
impl<T, R> UnwindSafe for BackgroundTaskConector<T, R>where
T: UnwindSafe,
R: UnwindSafe,