pub struct Button { /* private fields */ }Expand description
A button in the app bar.
Examples
use appcui::prelude::*;
let button = appbar::Button::new("Button", 0, appbar::Side::Left);Implementations
Sourceimpl Button
impl Button
Sourcepub fn new(caption: &str, order: u8, pos: Side) -> Self
pub fn new(caption: &str, order: u8, pos: Side) -> Self
Creates a new button with the specified caption, order and position.
Parameters
caption- The caption of the button. If the caption contains the&character, the next character (if it is a letter or number) will be set as a hot-key for the button. For example,"&Save"will set the hot-key toAlt+S.order- The order of the button (a number that determines the order of the button in the app bar - lower numbers are displayed first from either left or right depending on the pos parameter)pos- The position of the button (LeftorRight)
Example
use appcui::prelude::*;
let button = appbar::Button::new("Button", 0, appbar::Side::Left);Sourcepub fn with_tooltip(caption: &str, tooltip: &str, order: u8, pos: Side) -> Self
pub fn with_tooltip(caption: &str, tooltip: &str, order: u8, pos: Side) -> Self
Creates a new button with the specified caption, tooltip, order and position.
Parameters
caption- The caption of the button. If the caption contains the&character, the next character (if it is a letter or number) will be set as a hot-key for the button. For example,"&Save"will set the hot-key toAlt+S.tooltip- The tooltip associated with the button (it will be displayed when the mouse is over the button)order- The order of the button (a number that determines the order of the button in the app bar - lower numbers are displayed first from either left or right depending on the pos parameter)pos- The position of the button (LeftorRight)
Example
use appcui::prelude::*;
let button = appbar::Button::with_tooltip("Button", "Tooltip", 0, appbar::Side::Left);Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if the button is enabled, false otherwise.
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Enables or disables the button.
Sourcepub fn set_caption(&mut self, text: &str)
pub fn set_caption(&mut self, text: &str)
Sets the caption of the button. If the caption contains the & character, the next character (if it is a letter or number) will be set as a hot-key for the button. For example, "&Save" will set the hot-key to Alt+S.
Sourcepub fn set_tooltip(&mut self, text: &str)
pub fn set_tooltip(&mut self, text: &str)
Sets the tooltip of the button.