pub struct DropDownList<T>where
T: DropDownListType + 'static,{ /* private fields */ }Implementations
Sourceimpl<T> DropDownList<T>where
T: DropDownListType + 'static,
impl<T> DropDownList<T>where
T: DropDownListType + 'static,
Sourcepub fn new(layout: Layout, flags: Flags) -> Self
pub fn new(layout: Layout, flags: Flags) -> Self
Creates a new DropDownList control with the specified layout and flags. The flags can be a combination of the following values:
Flags::AllowNoneSelection- if set, the user can select no item from the DropDownListFlags::ShowDescription- if set, the description of the selected item will be displayed in the DropDownList
Example
use appcui::prelude::*;
struct MyObject { name: String, description: String }
impl DropDownListType for MyObject {
fn name(&self) -> &str { &self.name }
fn description(&self) -> &str { &self.description }
fn symbol(&self) -> &str { "" }
}
let mut db = DropDownList::<MyObject>::new(layout!("x:1,y:1,w:30"), dropdownlist::Flags::ShowDescription);
db.add(MyObject { name: "Item 1".to_string(), description: "Description 1".to_string() });
db.add(MyObject { name: "Item 2".to_string(), description: "Description 2".to_string() });
db.add(MyObject { name: "Item 3".to_string(), description: "Description 3".to_string() });Sourcepub fn with_symbol(symbol_size: u8, layout: Layout, flags: Flags) -> Self
pub fn with_symbol(symbol_size: u8, layout: Layout, flags: Flags) -> Self
Creates a new DropDownList control with the specified layout, symbol size and flags. The flags can be a combination of the following values:
Flags::AllowNoneSelection- if set, the user can select no item from the DropDownListFlags::ShowDescription- if set, the description of the selected item will be displayed in the DropDownList
The symbol size can be one of the following values: 0, 1, 2 or 3
Example
use appcui::prelude::*;
struct MyObject { name: String, symbol: &'static str }
impl DropDownListType for MyObject {
fn name(&self) -> &str { &self.name }
fn description(&self) -> &str { "" }
fn symbol(&self) -> &str { self.symbol }
}
let mut db = DropDownList::<MyObject>::with_symbol(1, layout!("x:1,y:1,w:30"), dropdownlist::Flags::None);
db.add(MyObject { name: "Sum".to_string(), symbol: "∑" });
db.add(MyObject { name: "Product".to_string(), symbol: "∏" });
db.add(MyObject { name: "Integral".to_string(), symbol: "∫" });Sourcepub fn add(&mut self, value: T)
pub fn add(&mut self, value: T)
Adds a new item to the DropDownList control
Example
use appcui::prelude::*;
struct MyObject { name: String, description: String, symbol: String }
impl MyObject {
fn new(name: &str, description: &str, symbol: &str) -> MyObject {
MyObject {
name: name.to_string(),
description: description.to_string(),
symbol: symbol.to_string()
}
}
}
impl DropDownListType for MyObject {
fn name(&self) -> &str { &self.name }
fn description(&self) -> &str { &self.description }
fn symbol(&self) -> &str { &self.symbol }
}
let mut db = DropDownList::<MyObject>::new(layout!("x:1,y:1,w:20"), dropdownlist::Flags::None);
db.add(MyObject::new("Heart", "Symbol of love", "❤"));
db.add(MyObject::new("Star", "Symbol of hope", "⭐"));
db.add(MyObject::new("Sun", "Symbol of light", "☀"));
Sourcepub fn selected_item(&self) -> Option<&T>
pub fn selected_item(&self) -> Option<&T>
Returns the selected item from the ComboBox control. If no item is selected, the code will return None
Sourcepub fn selected_item_mut(&mut self) -> Option<&mut T>
pub fn selected_item_mut(&mut self) -> Option<&mut T>
Returns the selected item from the ComboBox control. If no item is selected, the code will return None
Sourcepub fn index(&self) -> Option<u32>
pub fn index(&self) -> Option<u32>
Returns the index of the selected item. If no item is selected, the code will return None
Sourcepub fn item(&self, index: u32) -> Option<&T>
pub fn item(&self, index: u32) -> Option<&T>
Returns the item at the specified index. If the index is invalid, the code will return None
Sourcepub fn item_mut(&mut self, index: u32) -> Option<&mut T>
pub fn item_mut(&mut self, index: u32) -> Option<&mut T>
Returns the item at the specified index. If the index is invalid, the code will return None
Sourcepub fn set_index(&mut self, index: u32)
pub fn set_index(&mut self, index: u32)
Sets the selected item based on the provided index. If the index is invalid, the index will be ignored
Sourcepub fn has_selection(&self) -> bool
pub fn has_selection(&self) -> bool
Returns true if the ComboBox control has a selected item
Sourcepub fn set_none_string(&mut self, text: &str)
pub fn set_none_string(&mut self, text: &str)
Sets the string that will be displayed when no item is selected. By default, this is “None” if the flag AllowNoneSelection is set or an empty string otherwise
Methods from Deref<Target = ControlBase>
Sourcepub fn client_size(&self) -> Size
pub fn client_size(&self) -> Size
Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.
Sourcepub fn set_size(&mut self, width: u16, height: u16)
pub fn set_size(&mut self, width: u16, height: u16)
Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn position(&self) -> Point
pub fn position(&self) -> Point
Returns the relatove position (x,y) of the current control to its parent.
Sourcepub fn set_position(&mut self, x: i32, y: i32)
pub fn set_position(&mut self, x: i32, y: i32)
Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.
Sourcepub fn set_visible(&mut self, visible: bool)
pub fn set_visible(&mut self, visible: bool)
Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.
Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the buttonpub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)
pub fn expanded_size(&self) -> Size
Sourcepub fn request_focus(&mut self) -> bool
pub fn request_focus(&mut self) -> bool
A control can use this method to request focus
pub fn timer(&mut self) -> Option<&mut Timer>
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Returns true if the current control is visible or false otherwise
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if the current control is enabled or false otherwise
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Returns true if the current control is active (enabled and visible at the same time) or false otherwise
Sourcepub fn can_receive_input(&self) -> bool
pub fn can_receive_input(&self) -> bool
Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.
Sourcepub fn has_focus(&self) -> bool
pub fn has_focus(&self) -> bool
Returns true if the current control has the focus or false otherwise
Sourcepub fn is_mouse_over(&self) -> bool
pub fn is_mouse_over(&self) -> bool
Returns true if the mouse cursor is over the current control or false otherwise
Sourcepub fn set_size_bounds(
&mut self,
min_width: u16,
min_height: u16,
max_width: u16,
max_height: u16,
)
pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )
Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.
Sourcepub fn set_hotkey<T>(&mut self, hotkey: T)
pub fn set_hotkey<T>(&mut self, hotkey: T)
Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey
pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)
pub fn request_update(&self)
pub fn appbar(&mut self) -> &mut AppBar
pub fn theme(&self) -> &Theme
Sourcepub fn update_layout(&mut self, layout: Layout)
pub fn update_layout(&mut self, layout: Layout)
Updates the layout of the current control