Label

Struct Label 

pub struct Label { /* private fields */ }

Implementations

Source

impl Label

pub fn new(caption: &str, layout: Layout) -> Self

Creates a new label with the specified caption and layout. The caption can contain a hotkey (e.g. “File &Open”) and the layout is used to position the label on the screen. The label is a read-only control that can be used to display text on the screen. The label is not a focusable control and it does not accept any input.

Example
use appcui::prelude::*;
 
let mut label = Label::new("My Label", layout!("x:1,y:1,w:30"));
pub fn set_caption(&mut self, text: &str)

pub fn caption(&self) -> &str

Methods from Deref<Target = ControlBase>

pub fn size(&self) -> Size

Returns the size of a control

pub fn client_size(&self) -> Size

Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.

pub fn set_size(&mut self, width: u16, height: u16)

Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed. This method has no effect on a Desktop control.

pub fn position(&self) -> Point

Returns the relatove position (x,y) of the current control to its parent.

pub fn set_position(&mut self, x: i32, y: i32)

Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed. This method has no effect on a Desktop control.

pub fn set_enabled(&mut self, enabled: bool)

Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.

pub fn set_visible(&mut self, visible: bool)

Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.

Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the button
pub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)

pub fn expanded_size(&self) -> Size

pub fn request_focus(&mut self) -> bool

A control can use this method to request focus

pub fn timer(&mut self) -> Option<&mut Timer>

pub fn is_visible(&self) -> bool

Returns true if the current control is visible or false otherwise

pub fn is_enabled(&self) -> bool

Returns true if the current control is enabled or false otherwise

pub fn is_active(&self) -> bool

Returns true if the current control is active (enabled and visible at the same time) or false otherwise

pub fn can_receive_input(&self) -> bool

Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.

pub fn has_focus(&self) -> bool

Returns true if the current control has the focus or false otherwise

pub fn is_mouse_over(&self) -> bool

Returns true if the mouse cursor is over the current control or false otherwise

pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )

Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.

pub fn set_hotkey<T>(&mut self, hotkey: T)
where Key: From<T>,

Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey

pub fn hotkey(&self) -> Key

Returns the hotkey associated to a control or Key::None otherwise.

pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)

pub fn request_update(&self)

pub fn register_menu(&mut self, menu: Menu) -> Handle<Menu>

pub fn show_menu( &self, handle: Handle<Menu>, x: i32, y: i32, max_size: Option<Size>, )

pub fn menuitem<T>( &self, menu_handle: Handle<Menu>, menuitem_handle: Handle<T>, ) -> Option<&T>
where T: MenuItem,

pub fn menuitem_mut<T>( &mut self, menu_handle: Handle<Menu>, menuitem_handle: Handle<T>, ) -> Option<&mut T>
where T: MenuItem,

pub fn appbar(&mut self) -> &mut AppBar

pub fn theme(&self) -> &Theme

pub fn update_layout(&mut self, layout: Layout)

Updates the layout of the current control