pub struct ToggleButton { /* private fields */ }Implementations
Sourceimpl ToggleButton
impl ToggleButton
Sourcepub fn new(
caption: &str,
tooltip: &str,
layout: Layout,
selected: bool,
button_type: Type,
) -> Self
pub fn new( caption: &str, tooltip: &str, layout: Layout, selected: bool, button_type: Type, ) -> Self
Creates a new toggle button with the specified caption, tooltip, layout, selected state and button type.
The button type can be Normal or Underlined.
Examples
use appcui::prelude::*;
let mut button = ToggleButton::new("🐼",
"Enable Panda Mode",
layout!("x:1,y:1,w:2"),
false,
togglebutton::Type::Normal);Sourcepub fn with_single_selection(
caption: &str,
tooltip: &str,
layout: Layout,
selected: bool,
button_type: Type,
) -> Self
pub fn with_single_selection( caption: &str, tooltip: &str, layout: Layout, selected: bool, button_type: Type, ) -> Self
Creates a new toggle button with the specified caption, tooltip, layout, selected state and button type.
The button type can be Normal or Underlined.
This type of button is considered to be part of a group of buttons, and only one button can be selected at a time.
Example:
use appcui::prelude::*;
let panda = ToggleButton::with_single_selection("🐼",
"Enable Panda Mode",
layout!("x:1,y:1,w:2"),
false,
togglebutton::Type::Normal);
let dog = ToggleButton::with_single_selection("🐶",
"Enable Dog Mode",
layout!("x:3,y:1,w:2"),
true,
togglebutton::Type::Normal);Sourcepub fn set_caption(&mut self, caption: &str)
pub fn set_caption(&mut self, caption: &str)
Sets the caption of a toggle button.
Sourcepub fn is_selected(&self) -> bool
pub fn is_selected(&self) -> bool
Returns the state of the toggle button (pressed or not)
Sourcepub fn set_selected(&mut self, selected: bool)
pub fn set_selected(&mut self, selected: bool)
Sets the state of the toggle button (pressed or not).
If the button is part of a group of buttons, only one button can be selected at a time. As such, calling this function in this case with a false value will have no effect.
Methods from Deref<Target = ControlBase>
Sourcepub fn client_size(&self) -> Size
pub fn client_size(&self) -> Size
Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.
Sourcepub fn set_size(&mut self, width: u16, height: u16)
pub fn set_size(&mut self, width: u16, height: u16)
Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn position(&self) -> Point
pub fn position(&self) -> Point
Returns the relatove position (x,y) of the current control to its parent.
Sourcepub fn set_position(&mut self, x: i32, y: i32)
pub fn set_position(&mut self, x: i32, y: i32)
Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.
Sourcepub fn set_visible(&mut self, visible: bool)
pub fn set_visible(&mut self, visible: bool)
Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.
Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the buttonpub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)
pub fn expanded_size(&self) -> Size
Sourcepub fn request_focus(&mut self) -> bool
pub fn request_focus(&mut self) -> bool
A control can use this method to request focus
pub fn timer(&mut self) -> Option<&mut Timer>
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Returns true if the current control is visible or false otherwise
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if the current control is enabled or false otherwise
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Returns true if the current control is active (enabled and visible at the same time) or false otherwise
Sourcepub fn can_receive_input(&self) -> bool
pub fn can_receive_input(&self) -> bool
Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.
Sourcepub fn has_focus(&self) -> bool
pub fn has_focus(&self) -> bool
Returns true if the current control has the focus or false otherwise
Sourcepub fn is_mouse_over(&self) -> bool
pub fn is_mouse_over(&self) -> bool
Returns true if the mouse cursor is over the current control or false otherwise
Sourcepub fn set_size_bounds(
&mut self,
min_width: u16,
min_height: u16,
max_width: u16,
max_height: u16,
)
pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )
Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.
Sourcepub fn set_hotkey<T>(&mut self, hotkey: T)
pub fn set_hotkey<T>(&mut self, hotkey: T)
Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey
pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)
pub fn request_update(&self)
pub fn appbar(&mut self) -> &mut AppBar
pub fn theme(&self) -> &Theme
Sourcepub fn update_layout(&mut self, layout: Layout)
pub fn update_layout(&mut self, layout: Layout)
Updates the layout of the current control