A treeview UI control for displaying hierarchical data.
The TreeView control provides a way to display tree-structured data with collapsible nodes. It supports multiple selection modes, custom node rendering, and keyboard navigation.
Re-exports
pub use crate::ui::components::listitem::ListItem;pub use crate::ui::components::listitem::RenderMethod;
Modules
- events
- Events emitted by a
super::TreeView.
Structs
- Flags
- Initialization flags for a
super::TreeView. - Item
- A node in a
super::TreeView, wrapping aListItemvalue and parent/child links. - Tree
View - A hierarchical, multi-column view of items that implement
ListItem.
Enums
- Area
Format - Unit used when rendering an area value in a list item.
- Bool
Format - How a boolean list-item value is rendered as text.
- Currency
Format - Currency and symbol used when rendering a monetary list-item value.
- Date
Format - How a calendar-date list-item value is rendered.
- Date
Time Format - How a date-and-time list-item value is rendered.
- Distance
Format - Unit used when rendering a distance list-item value.
- Duration
Format - How a duration list-item value is rendered.
- Float
Format - Precision and grouping used when rendering a floating-point list-item value.
- Numeric
Format - How an integer list-item value is rendered.
- Percentage
Format - How a percentage list-item value is rendered.
- Rating
Format - How a rating list-item value is rendered.
- Size
Format - Unit used when rendering a byte-size list-item value.
- Speed
Format - Unit used when rendering a speed list-item value.
- Status
- Progress or lifecycle state of a list-item task.
- Status
Format - Visual style used when rendering a
Statusbar in a list item. - Temperature
Format - Temperature scale used when rendering a list-item value.
- Time
Format - How a time-of-day list-item value is rendered.
- Volume
Format - Unit used when rendering a volume list-item value.
- Weight
Format - Unit used when rendering a weight list-item value.