pub struct VSplitter { /* private fields */ }Implementations
Sourceimpl VSplitter
impl VSplitter
Sourcepub fn new<T>(pos: T, layout: Layout, resize_behavior: ResizeBehavior) -> Selfwhere
Coordinate: From<T>,
pub fn new<T>(pos: T, layout: Layout, resize_behavior: ResizeBehavior) -> Selfwhere
Coordinate: From<T>,
Creates a new Vertical Splitter control with the specified position, layout and resize behavior The position can be a percentage (e.g. a float value) or an absolute value (e.g. an unsigned value) The resize behavior can be one of the following values:
ResizeBehavior::PreserveAspectRatio- the aspect ratio of the panels is preserved when the splitter is resizedResizeBehavior::PreserveLeftPanelSize- the size of the left panel is preserved when the splitter is resizedResizeBehavior::PreserveRightPanelSize- the size of the right panel is preserved when the splitter is resized
Example
use appcui::prelude::*;
let mut vs = VSplitter::new(0.5,layout!("d:f"),vsplitter::ResizeBehavior::PreserveRightPanelSize);
vs.add(vsplitter::Panel::Left,panel!("Left,l:1,r:1,t:1,b:1"));
vs.add(vsplitter::Panel::Right,panel!("Right,l:1,r:1,t:1,b:1"));Sourcepub fn add<T>(&mut self, panel: Panel, control: T) -> Handle<T>
pub fn add<T>(&mut self, panel: Panel, control: T) -> Handle<T>
Adds a new control to the specified panel of the splitter (left or right)
Example
use appcui::prelude::*;
let mut vs = VSplitter::new(0.5,layout!("d:f"),vsplitter::ResizeBehavior::PreserveRightPanelSize);
vs.add(vsplitter::Panel::Left,button!("PressMe,x:1,y:1,w:12"));
vs.add(vsplitter::Panel::Right,button!("PressMe,x:1,y:1,w:12")); Sourcepub fn set_min_width<T>(&mut self, panel: Panel, min_size: T)
pub fn set_min_width<T>(&mut self, panel: Panel, min_size: T)
Sets the minimum width for the left or right panel The value can be a percentage (e.g. a float value) or an absolute value (e.g. an unsigned value)
Example
use appcui::prelude::*;
let mut vs = VSplitter::new(0.5,layout!("d:f"),vsplitter::ResizeBehavior::PreserveRightPanelSize);
vs.add(vsplitter::Panel::Left,button!("PressMe,x:1,y:1,w:12"));
vs.add(vsplitter::Panel::Right,button!("PressMe,x:1,y:1,w:12"));
// minim 10 chars from left
vs.set_min_width(vsplitter::Panel::Left,10);
// minim 20% from right
vs.set_min_width(vsplitter::Panel::Right,0.2);Sourcepub fn set_position<T>(&mut self, pos: T)where
Coordinate: From<T>,
pub fn set_position<T>(&mut self, pos: T)where
Coordinate: From<T>,
Sets the position of the splitter. The value can be a percentage (e.g. a float value) or an absolute value (e.g. an unsigned value)
Methods from Deref<Target = ControlBase>
Sourcepub fn client_size(&self) -> Size
pub fn client_size(&self) -> Size
Returns the client size of a control. In most cases it is the same as the size returned the method .get_size(). However, if the control has margins (for example in case of a Window) this size will be smaller.
Sourcepub fn set_size(&mut self, width: u16, height: u16)
pub fn set_size(&mut self, width: u16, height: u16)
Sets the new size for a control (to a specified size given by parameters width and height). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by controls x and y coordonates) and the new provided size. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn position(&self) -> Point
pub fn position(&self) -> Point
Returns the relatove position (x,y) of the current control to its parent.
Sourcepub fn set_position(&mut self, x: i32, y: i32)
pub fn set_position(&mut self, x: i32, y: i32)
Sets the new position for a control (to a specified coordonate given by parameters x and y). Keep in mind that this method will change the existing layout to an a layout based on top-left corner (given by coordonates x and y) and the controls current width and height. Any dock or alignment properties will be removed.
This method has no effect on a Desktop control.
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Sets the enabled state of a control. This method has no effect on a Desktop or a Window control that will always be enabled.
Sourcepub fn set_visible(&mut self, visible: bool)
pub fn set_visible(&mut self, visible: bool)
Can be used to make a control visible or not. This method has no effect on the Desktop control that will always be visible.
Examples
use appcui::prelude::*;
let mut button = button!("'Click me',x:1,y:1,w:15");
button.set_visible(false); // this will hide the buttonpub fn set_components_toolbar_margins(&mut self, left: u8, top: u8)
pub fn expanded_size(&self) -> Size
Sourcepub fn request_focus(&mut self) -> bool
pub fn request_focus(&mut self) -> bool
A control can use this method to request focus
pub fn timer(&mut self) -> Option<&mut Timer>
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Returns true if the current control is visible or false otherwise
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if the current control is enabled or false otherwise
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Returns true if the current control is active (enabled and visible at the same time) or false otherwise
Sourcepub fn can_receive_input(&self) -> bool
pub fn can_receive_input(&self) -> bool
Returns true if the current control can receive focus or false otherwise. If the control is not visible or it is disable this function will return false.
Sourcepub fn has_focus(&self) -> bool
pub fn has_focus(&self) -> bool
Returns true if the current control has the focus or false otherwise
Sourcepub fn is_mouse_over(&self) -> bool
pub fn is_mouse_over(&self) -> bool
Returns true if the mouse cursor is over the current control or false otherwise
Sourcepub fn set_size_bounds(
&mut self,
min_width: u16,
min_height: u16,
max_width: u16,
max_height: u16,
)
pub fn set_size_bounds( &mut self, min_width: u16, min_height: u16, max_width: u16, max_height: u16, )
Sets the bounds (minim and maxim sized allowed for a control). If the size of a control is outside its bounds, its size will be adjusted automatically. This method has no effect on a Desktop control.
Sourcepub fn set_hotkey<T>(&mut self, hotkey: T)
pub fn set_hotkey<T>(&mut self, hotkey: T)
Sets the hot-key associated with a control. Use Key::None to clear an existing hotkey
pub fn raise_custom_event(&self, class_hash: u64, event_id: u32)
pub fn request_update(&self)
pub fn appbar(&mut self) -> &mut AppBar
pub fn theme(&self) -> &Theme
Sourcepub fn update_layout(&mut self, layout: Layout)
pub fn update_layout(&mut self, layout: Layout)
Updates the layout of the current control